==> eiffelstudio-18.01.10.1424.tar: F_code/C10/xm472.c <==
/*
 * Code for class XM_XSLT_UTF32_ENCODER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm472.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XSLT_UTF32_ENCODER}.make */
void F1157_8636 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,arg2);
	RTLIU(6);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	tr1 = RTOSCF(8220,F1128_8220,(Current));
	tr2 = *(EIF_REFERENCE *)(Current);
	tr3 = RTMS_EX_H("UTF-32BE",8,345475141);
	tb1 = F1113_8059(RTCW(tr1), tr2, tr3);
	if (tb1) {
		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	} else {
		tr1 = RTOSCF(8220,F1128_8220,(Current));
		tr2 = *(EIF_REFERENCE *)(Current);
		tr3 = RTMS_EX_H("UTF-32LE",8,345477701);
		tb1 = F1113_8059(RTCW(tr1), tr2, tr3);
		if (tb1) {
			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		} else {
		}
	}
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg2;
	RTLE;
}

/* {XM_XSLT_UTF32_ENCODER}.byte_order_mark */
static EIF_REFERENCE F1157_8637_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	

	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (8637);
#define Result RTOSR(8637)
	RTOC_NEW(Result);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
		Result = RTOSCF(7980,F1104_7980,(RTCV(RTOSCF(2274,F477_2274,(Current)))));
	} else {
		Result = RTOSCF(7979,F1104_7979,(RTCV(RTOSCF(2274,F477_2274,(Current)))));
	}
	RTOSE (8637);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1157_8637 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(8637,F1157_8637_body,(Current));
}

/* {XM_XSLT_UTF32_ENCODER}.byte_order_mark_permitted */
EIF_BOOLEAN F1157_8640 (EIF_REFERENCE Current)
{
	GTCX
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	
	
	Result = *(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) !(EIF_BOOLEAN) (Result || *(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_));
	return Result;
}

/* {XM_XSLT_UTF32_ENCODER}.is_byte_order_mark_default */
EIF_BOOLEAN F1157_8641 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
}

/* {XM_XSLT_UTF32_ENCODER}.is_bad_character_code */
EIF_BOOLEAN F1157_8642 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
}

/* {XM_XSLT_UTF32_ENCODER}.output */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F1157_8643 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_REFERENCE  EIF_VOLATILE tr2 = NULL;
	RTLD;
	RTXD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,arg1);
	RTLR(4,saved_except);
	RTLIU(5);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = RTOSCF(8220,F1128_8220,(Current));
			tr2 = F1113_8054(RTCW(tr2), arg1);
			F1516_12780(RTCW(tr1), tr2);
		} else {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = RTOSCF(8220,F1128_8220,(Current));
			tr2 = F1113_8053(RTCW(tr2), arg1);
			F1516_12780(RTCW(tr1), tr2);
		}
	}
	RTE_E
	RTXSC;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		RTER;
	}
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {XM_XSLT_UTF32_ENCODER}.output_ignoring_error */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F1157_8644 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	RTLD;
	RTXD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,saved_except);
	RTLIU(4);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1516_12780(RTCW(tr1), arg1);
	}
	RTE_E
	RTXSC;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		RTER;
	}
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

void EIF_Minit472 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C10/xm472.c <==
/*
 * Code for class XM_XSLT_UTF8_ENCODER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm472.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XSLT_UTF8_ENCODER}.make */
void F1157_8640 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLIU(3);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg2;
	RTLE;
}

/* {XM_XSLT_UTF8_ENCODER}.byte_order_mark */
static EIF_REFERENCE F1157_8641_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (8641);
#define Result RTOSR(8641)
	RTOC_NEW(Result);
	tr1 = RTOSCF(4634,F939_4634,(Current));
	Result = F1631_14215(RTCW(tr1), (EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 254L) * ((EIF_INTEGER_32) 256L)) + ((EIF_INTEGER_32) 255L)));
	RTOSE (8641);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1157_8641 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(8641,F1157_8641_body,(Current));
}

/* {XM_XSLT_UTF8_ENCODER}.byte_order_mark_permitted */
EIF_BOOLEAN F1157_8642 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
}

/* {XM_XSLT_UTF8_ENCODER}.is_byte_order_mark_default */
EIF_BOOLEAN F1157_8643 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
}

/* {XM_XSLT_UTF8_ENCODER}.is_bad_character_code */
EIF_BOOLEAN F1157_8644 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
}

/* {XM_XSLT_UTF8_ENCODER}.output */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F1157_8645 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	RTLD;
	RTXD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,saved_except);
	RTLIU(4);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1516_12782(RTCW(tr1), arg1);
	}
	RTE_E
	RTXSC;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		RTER;
	}
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {XM_XSLT_UTF8_ENCODER}.output_ignoring_error */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F1157_8646 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	RTLD;
	RTXD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,saved_except);
	RTLIU(4);
	RTXSLS;
	
	RTEV;
	RTGC;
	RTE_T
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1516_12782(RTCW(tr1), arg1);
	}
	RTE_E
	RTXSC;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		RTER;
	}
	/* NOTREACHED */
	RTE_EE
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

void EIF_Minit472 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
